==> Iuno-3.2.9.11259.tar.gz: Iuno-3.2.9.11259/Iuno/shop/Util.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: Util.py 11261 2018-11-15 19:36:42Z Lavender $
#
# Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-11-16 03:36:42 +0800 (Fri, 16 Nov 2018) $
# $Revision: 11261 $

import sys
import hashlib

from collections import OrderedDict

if sys.version_info.major == 3:
    from urllib.parse import urlencode
else:
    from urllib import urlencode

# ​https://github.com/vinta/python-pay2go

class Pay2GoMPGAPI(object):

    def __init__(self, hashKey, hashIv, sandbox, *args, **kwargs):
        self.hashKey = hashKey
        self.hashIv = hashIv
        if sandbox:
            self.ApiUrl = 'https://ccore.spgateway.com/MPG/mpg_gateway'
        else:
            self.ApiUrl = 'https://core.spgateway.com/MPG/mpg_gateway'

        self.requiredFields = (
            'Amt',
            'MerchantID',
            'MerchantOrderNo',
            'TimeStamp',
            'Version',
        )

    def buildFormData(self, data):
        def generateCheckValue(data):
            orderedDict = OrderedDict()

            orderedDict['HashKey'] = self.hashKey
            for field in self.requiredFields:
                orderedDict[field] = data[field]
            orderedDict['HashIV'] = self.hashIv

            checkValue = hashlib.sha256(
                urlencode(orderedDict).encode('utf-8')).hexdigest().upper()

            return checkValue

        formData = dict(data)
        formData['CheckValue'] = generateCheckValue(data)

        return formData

    def createPayment(self, data):
        payment = Payment(
            formAction=self.ApiUrl,
            formData=self.buildFormData(data)
        )

        return payment

CATHAPBK_SERVICE_URL = \
    'https://sslpayment.uwccb.com.tw/EPOSService/Payment/OrderInitial.aspx'

from django.template.loader import get_template
from django.template import Context

class CathaybkAPI(object):

    def __init__(self, merchantId, cubkey):
        self.merchantId = merchantId
        self.cubkey = cubkey

    def generateCheckValue(self, data):
        checkValue = hashlib.md5(
            self.merchantId + data['ORDERNUMBER'] + 
            str(data['AMOUNT']) + self.cubkey).hexdigest()
        return checkValue

    def buildXml(self, data):
        temp = get_template('shop/payment/Cathaybk.xml')
        context = Context({
            'data': data,
            'checkValue': self.generateCheckValue(data),
            'merchantId': self.merchantId,
        })
        xml = temp.render(context)
        return xml

    def buildForm(self, data):
        xml = self.buildXml(data)
        temp = get_template('shop/payment/Cathaybk.html')
        context = Context({
            'xml': xml,
            'apiUrl': CATHAPBK_SERVICE_URL,
        })
        form = temp.render(context)
        return form
        


class Payment(object):

    def __init__(self, formAction, formData, *args, **kwargs):
        self.formAction = formAction
        self.formData = formData

class ECPayShopShipment(object):
    def __init__(self, hashKey, hashIv, sandbox, *args, **kwargs):
        self.hashKey = hashKey
        self.hashIv = hashIv
        if sandbox:
            self.ApiUrl = 'https://vendor-stage.ecpay.com.tw'
        else:
            self.ApiUrl = 'https://vendor.ecpay.com.tw'

==> Iuno-3.2.15.11319.tar.gz: Iuno-3.2.15.11319/Iuno/shop/Util.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: Util.py 11263 2018-11-22 14:47:09Z Lavender $
#
# Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $ (last)
# $Date: 2018-11-22 23:47:09 +0900 (週四, 22 十一月 2018) $
# $Revision: 11263 $

import sys
import hashlib
import urllib

from collections import OrderedDict

from django.conf import settings

if sys.version_info.major == 3:
    from urllib.parse import urlencode
else:
    from urllib import urlencode

from Iuppiter.Encoding import utf8

# ​https://github.com/vinta/python-pay2go

class Pay2GoMPGAPI(object):

    def __init__(self, hashKey, hashIv, sandbox, *args, **kwargs):
        self.hashKey = hashKey
        self.hashIv = hashIv
        if sandbox:
            self.ApiUrl = 'https://ccore.spgateway.com/MPG/mpg_gateway'
        else:
            self.ApiUrl = 'https://core.spgateway.com/MPG/mpg_gateway'

        self.requiredFields = (
            'Amt',
            'MerchantID',
            'MerchantOrderNo',
            'TimeStamp',
            'Version',
        )

    def buildFormData(self, data):
        def generateCheckValue(data):
            orderedDict = OrderedDict()

            orderedDict['HashKey'] = self.hashKey
            for field in self.requiredFields:
                orderedDict[field] = data[field]
            orderedDict['HashIV'] = self.hashIv

            checkValue = hashlib.sha256(
                urlencode(orderedDict).encode('utf-8')).hexdigest().upper()

            return checkValue

        formData = dict(data)
        formData['CheckValue'] = generateCheckValue(data)

        return formData

    def createPayment(self, data):
        payment = Payment(
            formAction=self.ApiUrl,
            formData=self.buildFormData(data)
        )

        return payment

CATHAPBK_SERVICE_URL = \
    'https://sslpayment.uwccb.com.tw/EPOSService/Payment/OrderInitial.aspx'

from django.template.loader import get_template
from django.template import Context

class CathaybkAPI(object):

    def __init__(self, merchantId, cubkey):
        self.merchantId = merchantId
        self.cubkey = cubkey

    def generateCheckValue(self, data):
        checkValue = hashlib.md5(
            self.merchantId + data['ORDERNUMBER'] + 
            str(data['AMOUNT']) + self.cubkey).hexdigest()
        return checkValue

    def buildXml(self, data):
        temp = get_template('shop/payment/Cathaybk.xml')
        context = Context({
            'data': data,
            'checkValue': self.generateCheckValue(data),
            'merchantId': self.merchantId,
        })
        xml = temp.render(context)
        return xml

    def buildForm(self, data):
        xml = self.buildXml(data)
        temp = get_template('shop/payment/Cathaybk.html')
        context = Context({
            'xml': xml,
            'apiUrl': CATHAPBK_SERVICE_URL,
        })
        form = temp.render(context)
        return form
        


class Payment(object):

    def __init__(self, formAction, formData, *args, **kwargs):
        self.formAction = formAction
        self.formData = formData

class ECPayShopShipment(object):
    def __init__(self, hashKey, hashIv, sandbox, *args, **kwargs):
        self.hashKey = hashKey
        self.hashIv = hashIv
        if sandbox:
            self.ApiUrl = 'https://vendor-stage.ecpay.com.tw'
        else:
            self.ApiUrl = 'https://vendor.ecpay.com.tw'

def createCheckValue(data):
    data = OrderedDict(data)
    data = OrderedDict(sorted(data.iteritems()))

    orderedDict = OrderedDict()
    orderedDict['HashKey'] = settings.ECPAY_API_HASH_KEY
    for field in data:
        orderedDict[field] = data[field]

    orderedDict['HashIV'] = settings.ECPAY_API_HASH_IV

    dataList = []
    for k, v in orderedDict.items():
        dataList.append("%s=%s" % (k, v))
    dataStr = u"&".join(dataList)

    encodeStr = urllib.urlencode({'data': utf8(dataStr),})[5:]
    checkValue = hashlib.md5(encodeStr.lower()).hexdigest().upper()
    return checkValue
